Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(551)

Unified Diff: ui/base/test/scoped_fake_nswindow_focus.h

Issue 1894383002: MacViews: Implement Full Keyboard Access. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@SetFocusBehavior
Patch Set: Rebased Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/base/test/scoped_fake_nswindow_focus.h
diff --git a/ui/base/test/scoped_fake_nswindow_focus.h b/ui/base/test/scoped_fake_nswindow_focus.h
index c166365b1646139043665121a2834ae6e1304e06..deeb8045d281e428e13ea6b55a5a479e667ada91 100644
--- a/ui/base/test/scoped_fake_nswindow_focus.h
+++ b/ui/base/test/scoped_fake_nswindow_focus.h
@@ -18,9 +18,9 @@ class ScopedObjCClassSwizzler;
namespace ui {
namespace test {
// Simulates key and main status by listening for -makeKeyWindow and
// -makeMainWindow. This allows test coverage of code relying on window focus
// changes without resorting to an interactive_ui_test.
class ScopedFakeNSWindowFocus {
public:
ScopedFakeNSWindowFocus();
@@ -31,6 +31,7 @@ class ScopedFakeNSWindowFocus {
std::unique_ptr<base::mac::ScopedObjCClassSwizzler> make_main_swizzler_;
std::unique_ptr<base::mac::ScopedObjCClassSwizzler> is_key_swizzler_;
std::unique_ptr<base::mac::ScopedObjCClassSwizzler> make_key_swizzler_;
+ std::unique_ptr<base::mac::ScopedObjCClassSwizzler> order_out_swizzler_;
DISALLOW_COPY_AND_ASSIGN(ScopedFakeNSWindowFocus);
};
@@ -18,9 +18,9 @@ class ScopedObjCClassSwizzler;
namespace ui {
namespace test {
-// Simulates key and main status by listening for -makeKeyWindow and
-// -makeMainWindow. This allows test coverage of code relying on window focus
-// changes without resorting to an interactive_ui_test.
+// Simulates key and main status by listening for -makeKeyWindow,
+// -makeMainWindow and -orderOut:. This allows test coverage of code relying on
+// window focus changes without resorting to an interactive_ui_test.
class ScopedFakeNSWindowFocus {
public:

Powered by Google App Engine
This is Rietveld 408576698